function [Tz, fidS] = JONSWAP(Deploy, Hs, Tp, g)
%% Defining parameters
fp = 1./Tp;
gamma = 3.3;
sigma_a = 0.07;
sigma_b = 0.09;
delta_f = 0.001;
delta_omega = 2*pi*delta_f;
f = [0.001:delta_f:1];
omega = 2.*pi.*f;
Tz = zeros(size(Tp,2)+1,size(Hs,2)+1);

%% Computing the spectrum
for j = 1:length(Tp)
    for k = 1:length(Hs)        
        Sf = zeros(1,size(f,2));
        Sw = zeros(1,size(f,2));
        
        alpha(j,k) = (Hs(1,k)/(4*g))^2*(2*pi*fp(1,j))^4*(0.065*gamma^0.803 + 0.135)^-1;
        
        for i = 1:length(f)
            if f(1,i) <= fp(1,j)
                sigma = sigma_a;
            else
                sigma = sigma_b;
            end           
            Sf(1,i) = alpha(j,k)*g^2*(2*pi)^-4*f(1,i)^-5*exp(-5/4*(fp(1,j)/f(1,i))^4)*gamma^exp(-(f(1,i)/fp(1,j)-1)^2/(2*sigma^2));
            Sw(1,i) = Sf(1,i)/(2*pi);
        end
%% Possibility to plot spectrum. If desirable remove comment signs      
%         figure(k+(j-1)*length(Hs)+100);
%         plot(f,Sf)
%         title(sprintf('Hs = %0.1f, Tp = %d', Hs(1,k), Tp(1,j)))
%         xlabel('Frequency [1/s]')
%         ylabel('Spectrum [m^2s]')
 
%% Estimate Tz
        m0 = sum(Sw,2)*delta_omega;
        m2 = sum((Sw.*omega.^2),2)*delta_omega;    
        Tz(j+1,k+1) = 1/(1/(2*pi)*sqrt(m2/m0));
    end
end

Tz(1,2:size(Tz,2)) = Hs;
Tz(2:size(Tz,1),1) = Tp;

%% Write Tz results to text file Jonswap_Tz
fidS = fopen('Jonswap_Tz.txt', 'w');
fprintf(fidS, 'Tz values for the JONSWAP spectrum\n\n');
fprintf(fidS, 'Hs values are given in the top row, Tp values in the first column\n');
fprintf(fidS, '-----------------------------------------------------------------\n');
if Deploy == 2
    for i = 1:size(Tz,1)
         fprintf(fidS,'%5.2f %5.2f %5.2f %5.2f %5.2f %5.2f %5.2f\n', Tz(i,:));
    end
else
    for i = 1:size(Tz,1)
         fprintf(fidS,'%5.2f %5.2f %5.2f %5.2f %5.2f %5.2f %5.2f %5.2f %5.2f\n', Tz(i,:));
    end
end
fprintf(fidS, '-----------------------------------------------------------------\n');
end
