function [Vel_mp] = M_velocity(headings, Hs, Tp, g, Tz_calc)
%% Defining parameters
rho = 1025;
Draft = 7.8;
kappa = 0.46;
neta = 0.19;
A_mp = 105;
M_wp = rho*A_mp*(Draft + kappa*sqrt(A_mp));
K_wp = rho*g*A_mp;
omega0 = sqrt(K_wp/M_wp);

%% Upload Normand Subsea heave transfer functions wave headings 0-180
Gs = load('Gs.txt');
T = Gs(:,1)';
omega = 2.*pi./T;

%Extraxt transfer functions
for i = 1:length(headings)
   Gs_amp(1,:,i) = Gs(:,i*2); 
   Gs_phi(1,:,i) = Gs(:,1+i*2)*pi/180;
   
   %Compute moonpool water plug elevation ratio to wave elevation
   for j = 1:length(Gs_phi(1,:,i))
       if Gs_phi(1,j,i) >= 0 && Gs_phi(1,j,i) < pi/2;
           Real_Gs(1,j,i) = Gs_amp(1,j,i)/sqrt(tan(Gs_phi(1,j,i))^2 + 1);
           Im_Gs(1,j,i) = sqrt(Gs_amp(1,j,i)^2 - Real_Gs(1,j,i)^2);          
       elseif Gs_phi(1,j,i) > pi/2 && Gs_phi(1,j,i) < pi;
           Real_Gs(1,j,i) = - Gs_amp(1,j,i)/sqrt(tan(Gs_phi(1,j,i))^2 + 1);
           Im_Gs(1,j,i) = sqrt(Gs_amp(1,j,i)^2 - Real_Gs(1,j,i)^2);
       elseif Gs_phi(1,j,i) >= pi && Gs_phi(1,j,i) < 3*pi/4;
           Real_Gs(1,j,i) = - Gs_amp(1,j,i)/sqrt(tan(Gs_phi(1,j,i))^2 + 1);
           Im_Gs(1,j,i) = - sqrt(Gs_amp(1,j,i)^2 - Real_Gs(1,j,i)^2);
       else Gs_phi(1,j,i) > 3*pi/4 && Gs_phi(1,j,i) < 2*pi;
           Real_Gs(1,j,i) = Gs_amp(1,j,i)/sqrt(tan(Gs_phi(1,j,i))^2 + 1);
           Im_Gs(1,j,i) = - sqrt(Gs_amp(1,j,i)^2 - Real_Gs(1,j,i)^2);
       end
       Ratio_transfer(1,j,i) = sqrt(Real_Gs(1,j,i)^2+Im_Gs(1,j,i)^2);
       
       Real_Gw(1,j,i) = rho*A_mp*(g*exp(-omega(1,j)^2/g*Draft)- omega(1,j)^2*kappa*sqrt(A_mp)*Real_Gs(1,j,i));
       Im_Gw(1,j,i) = - rho*A_mp*omega(1,j)^2*kappa*sqrt(A_mp)*Im_Gs(1,j,i);
   
       freq_rat(1,j) = omega(1,j)/omega0;
   
       Real_ratio_num(1,j,i) = (Real_Gw(1,j,i)/(rho*g*A_mp)-Im_Gs(1,j,i)*2*neta*freq_rat(1,j))*(1-freq_rat(1,j)^2)+(Real_Gs(1,j,i)*4*neta^2*freq_rat(1,j)+Im_Gw(1,j,i)/(rho*g*A_mp)*2*neta)*freq_rat(1,j);
       Im_ratio_num(1,j,i) = (Im_Gw(1,j,i)/(rho*g*A_mp)+Real_Gs(1,j,i)*2*neta*freq_rat(1,j))*(1-freq_rat(1,j)^2)+(Im_Gs(1,j,i)*4*neta^2*freq_rat(1,j)-Real_Gw(1,j,i)/(rho*g*A_mp)*2*neta)*freq_rat(1,j);
       ratio_denom(1,j,i) = 1-2*freq_rat(1,j)^2+freq_rat(1,j)^4+4*neta^2*freq_rat(1,j)^2;
   
       Real_ratio(1,j,i) = Real_ratio_num(1,j,i)/ratio_denom(1,j,i);
       Im_ratio(1,j,i) = Im_ratio_num(1,j,i)/ratio_denom(1,j,i);
       Ratio_amp(1,j,i) = sqrt(Real_ratio(1,j,i)^2+Im_ratio(1,j,i)^2);
   end
   
   for j = 1:length(Tp)
       for k = 1:length(Hs)
            [X,Y] = find(T == Tp(1,j));
            RAO_mp(j,1,i) = Ratio_amp(1,Y,i);
            Amp_mp(j,k,i) = RAO_mp(j,1,i)*Hs(1,k)*0.9;
            Vel_mp(j,k,i) = Amp_mp(j,k,i)/(0.5*Tz_calc(j+1,k+1,1));
       end
   end
end

Ratio_transfer;

%% Possible to plot water plug to wave elevation RAO
% for i = 1:length(headings)
% figure(i*400)
% plot((T.*omega0./(2.*pi))', Ratio_amp(1,:,i), '*-')
% xlabel('T/T_0 [s/s]')
% ylabel('Water plug elevation/wave elevation [m/m]')
% grid on
% title(sprintf('Wave Heading %d', headings(1,i)))
% end

end