function [Tz, fidS] = Torsethaugen(Deploy, Hs, Tp, g)
%% Define parameters
delta_f = 0.001;
delta_omega = 2*pi*delta_f;
f = [0.001:delta_f:1];
omega = 2.*pi.*f;
Tz = zeros(size(Tp,2)+1,size(Hs,2)+1);
F = 1:(length(Hs)*length(Tp));

%% Compute the spectrum
for j = 1:length(Tp)
    for k = 1:length(Hs)

        S1 = zeros(1,size(f,2));
        S2 = zeros(1,size(f,2));
        Sf = zeros(1,size(f,2));
        Sw = zeros(1,size(f,2));
    
        %Define spectrum parameters
        af = 6.6; 
        ae = 2.0;
        au = 25; 
        a10 = 0.7;
        a1 = 0.5;
        kg = 35.0;
        b1 = 2.0;
        a20 = 0.6;
        a2 = 0.3;
        a3 = 6;

        %Calculating parameters
        Tpf = af*Hs(1,k)^(1/3);
        Tl = ae*Hs(1,k)^0.5;
        Tu = au;

        if Tp(1,j) > Tl || Tp(1,j) < Tu
            el = (Tpf-Tp(1,j))/(Tpf-Tl);
            eu = (Tp(1,j)-Tpf)/(Tu-Tpf);
        else
            el = 1;
            eu = 1;
        end

        %If Tp < Tpf the sea state is wind dominated and if Tp >= Tpf the sea
        %state is swell dominated.
        if Tp(1,j) < Tpf
            %Primary peak
            Rw = (1-a10)*exp(-(el/a1)^2) + a10;
            H1 = Rw*Hs(1,k);
            Tp1 = Tp(1,j);
            sp = (2*pi/g)*H1/(Tp1^2);
            gamma1 = kg*sp^(6/7);
            %Secondary peak
            H2 = ((1-Rw^2)^0.5)*Hs(1,k);
            Tp2 = Tpf + b1;
            gamma2 = 1;    
        else
            %Primary peak
            Rs = (1-a20)*exp(-(eu/a2)^2) + a20;
            H1 = Rs*Hs(1,k);
            Tp1 = Tp(1,j);
            sf = (2*pi/g)*Hs(1,k)/Tpf^2;
            gammaf = kg*sf^(6/7);
            gamma1 = gammaf*(1 + a3*eu);
            %Secondary peak
            H2 = ((1-Rs^2)^0.5)*Hs(1,k);
            Tp2 = af*H2^(1/3);
            gamma2 = 1;
        end

        E1 = (1/16)*H1^2*Tp1;
        E2 = (1/16)*H2^2*Tp2;
        G0 = 3.26;
        Agamma = (1 + 1.1*log(gamma1)^1.19)/gamma1;

        for i = 1:length(f)
            f1 = f(1,i)*Tp1;
            f2 = f(1,i)*Tp2;    
            if f1 < 1
                sigma = 0.07;
            else
                sigma = 0.09;
            end
        
            S1(1,i) = G0*Agamma*(f1^-4)*exp(-(f1^-4))*gamma1^(exp((-1/(2*sigma^2))*(f1-1)^2));
            S2(1,i) = G0*(f2^-4)*exp(-(f2^-4));
            Sf(1,i) = E1*S1(1,i) + E2*S2(1,i); 
            Sw(1,i) = Sf(1,i)/(2*pi);
        end
%% Estimate Tz
        m0 = sum(Sw,2)*delta_omega;
        m2 = sum((Sw.*omega.^2),2)*delta_omega;    
        Tz(j+1,k+1) = 1/(1/(2*pi)*sqrt(m2/m0));
   
%% Construct MACSI2 spectrum input file        
        [Chosen_f, Chosen_Sf] = MACSI2spectrum(k, j, Hs, Tp, f, Sf);
        
%% Possibility to plot spectrum. If desirable remove comment sign.  
%         THspectrum_plot(Hs, Tp, k, j, f, Sf, Chosen_f, Chosen_Sf)
    end
end

Tz(1,2:size(Tz,2)) = Hs;
Tz(2:size(Tz,1),1) = Tp;

%% Write Tz results to text file Torsethaugen_Tz
fidS = fopen('Torsethaugen_Tz.txt', 'w');
fprintf(fidS, 'Tz values for the Torsethaugen spectra\n\n');
fprintf(fidS, 'Hs values are given in the top row, Tp values in the first column\n');
fprintf(fidS, '-----------------------------------------------------------------\n');
if Deploy == 2
    for i = 1:size(Tz,1)
         fprintf(fidS,'%5.2f %5.2f %5.2f %5.2f %5.2f %5.2f %5.2f\n', Tz(i,:));
    end
else
    for i = 1:size(Tz,1)
         fprintf(fidS,'%5.2f %5.2f %5.2f %5.2f %5.2f %5.2f %5.2f %5.2f %5.2f\n', Tz(i,:));
    end
end
fprintf(fidS, '-----------------------------------------------------------------\n');
end

